@@ -21,12 +21,16 @@ class FileLoader {
 			$jsLoadingSequence[] = "client/extjs/ext-all.js";
 			$jsLoadingSequence[] = "client/extjs/ux/ux-all.js";
 			$jsLoadingSequence[] = "client/extjs-mod/extjs-mod.js";
+			$jsLoadingSequence[] = "client/jquery/jquery-1.6.2.min.js";
+			$jsLoadingSequence[] = "client/tinymce/tiny_mce.js";
 			$jsLoadingSequence[] = "client/third-party/ux-thirdparty.js";
 		} else if ($load == LOAD_DEBUG) {
 			$jsLoadingSequence[] = "client/extjs/ext-base-debug.js";
 			$jsLoadingSequence[] = "client/extjs/ext-all-debug.js";
 			$jsLoadingSequence[] = "client/extjs/ux/ux-all-debug.js";
 			$jsLoadingSequence[] = "client/extjs-mod/extjs-mod-debug.js";
+			$jsLoadingSequence[] = "client/jquery/jquery-1.6.2.min.js";
+			$jsLoadingSequence[] = "client/tinymce/tiny_mce_src.js";
 			$jsLoadingSequence[] = "client/third-party/ux-thirdparty-debug.js";
 		} else {
 			$jsLoadingSequence[] = "client/extjs/ext-base-debug.js";
@@ -38,6 +42,8 @@ class FileLoader {
 					$this->getListOfFiles('js', 'client/extjs-mod')
 				)
 			);
+			$jsLoadingSequence[] = "client/jquery/jquery-1.6.2.min.js";
+			$jsLoadingSequence[] = "client/tinymce/tiny_mce_src.js";
 			$jsLoadingSequence = array_merge(
 				$jsLoadingSequence,
 				$this->buildJSLoadingSequence(
@@ -64,19 +70,22 @@ class FileLoader {
 			$cssLoadingSequence[] = "client/extjs/resources/css/ext-all.css";
 			$cssLoadingSequence[] = "client/extjs/ux/css/ux-all.css";
 			$cssLoadingSequence[] = "client/third-party/resources/css/ux-thirdparty.css";
+			$cssLoadingSequence[] = "client/tinymce/themes/advanced/skins/default/ui.css";
 		} else if ($load == LOAD_DEBUG) {
 			$cssLoadingSequence[] = "client/extjs/resources/css/ext-all.css";
 			$cssLoadingSequence[] = "client/extjs/ux/css/ux-all.css";
 			$cssLoadingSequence[] = "client/third-party/resources/css/ux-thirdparty.css";
+			$cssLoadingSequence[] = "client/tinymce/themes/advanced/skins/default/ui.css";
 		} else {
 			$cssLoadingSequence[] = "client/extjs/resources/css/ext-all.css";
 			$cssLoadingSequence[] = "client/extjs/ux/css/ux-all.css";
 			$cssLoadingSequence = array_merge(
 				$cssLoadingSequence,
 				$this->buildCSSLoadingSequence(
-					$this->getListOfFiles('css', 'client/third-party/resources/css')
+					$this->getListOfFiles('css', 'client/third-party')
 				)
 			);
+			$cssLoadingSequence[] = "client/tinymce/themes/advanced/skins/default/ui.css";
 		}
 
 		return $cssLoadingSequence;
@@ -210,7 +219,7 @@ class FileLoader {
 	 * Print each file on a new line using the given $template
 	 * @param Array $files The files to print
 	 * @param String $template The template used to print each file, the string {file} will
-	 * be replaced with the filename 
+	 * be replaced with the filename
 	 * @param Boolean $base True if only the basename of the file must be printed
 	 */
 	public function printFiles($files, $template = '{file}', $base = false)
@@ -223,11 +232,11 @@ class FileLoader {
 	/**
 	 * getJavascriptFiles
 	 *
-	 * Scanning files and subdirectories that can be found withing the supplied 
-	 * path and add all located Javascript files to a list. 
+	 * Scanning files and subdirectories that can be found withing the supplied
+	 * path and add all located Javascript files to a list.
 	 * @param $path String Path of the directory to scan
 	 * @param $recursive Boolean If set to true scans subdirectories as well
-	 * @param $excludeFiles Array Optional Paths of files or directories that 
+	 * @param $excludeFiles Array Optional Paths of files or directories that
 	 *                                     are excluded from the search.
 	 * @return Array List of arrays containing the paths to files that have to be included.
 	 */
@@ -238,11 +247,11 @@ class FileLoader {
 	/**
 	 * getCSSFiles
 	 *
-	 * Scanning files and subdirectories that can be found withing the supplied 
-	 * path and add all located CSS files to a list. 
+	 * Scanning files and subdirectories that can be found withing the supplied
+	 * path and add all located CSS files to a list.
 	 * @param $path String Path of the directory to scan
 	 * @param $recursive Boolean If set to true scans subdirectories as well
-	 * @param $excludeFiles Array Optional Paths of files or directories that 
+	 * @param $excludeFiles Array Optional Paths of files or directories that
 	 *                                     are excluded from the search.
 	 * @return Array List of arrays containing the paths to files that have to be included.
 	 */
@@ -252,19 +261,19 @@ class FileLoader {
 
 	/**
 	 * getListOfFiles
-	 * 
-	 * Scanning files and subdirectories that can be found withing the supplied 
-	 * path and add the files to a list. 
+	 *
+	 * Scanning files and subdirectories that can be found withing the supplied
+	 * path and add the files to a list.
 	 * @param $ext The extension of files that are included ("js" or "css")
 	 * @param $path String Path of the directory to scan
 	 * @param $recursive Boolean If set to true scans subdirectories as well
-	 * @param $excludeFiles Array Optional Paths of files or directories that 
+	 * @param $excludeFiles Array Optional Paths of files or directories that
 	 *                                     are excluded from the search.
 	 * @return Array List of arrays containing the paths to files that have to be included.
 	 */
 	private function getListOfFiles($ext, $path, $recursive = true, $excludeFiles = Array()) {
 		/*
-		 * We are using two lists of files to make sure the files from the 
+		 * We are using two lists of files to make sure the files from the
 		 * subdirectories are added after the current directory files.
 		 */
 		$files = Array();
@@ -296,7 +305,7 @@ class FileLoader {
 		}
 
 		/*
-		 * Make the lists alphabetically sorted, doing this separate makes sure 
+		 * Make the lists alphabetically sorted, doing this separate makes sure
 		 * the subdirectories are added after the files in the directory above.
 		 */
 		sort($files);
@@ -327,7 +336,7 @@ class FileLoader {
 			$content = $this->getFileContents($filename);
 
 			$dependsFile = Array();
-			
+
 			preg_match_all('(#dependsFile\W([^\n\r\*]+))', $content, $dependsFile);
 
 			$fileDataLookup[ $filename ] = Array(
@@ -362,12 +371,12 @@ class FileLoader {
 		return $fileSequence;
 	}
 
-	/** 
+	/**
 	 * buildJSLoadingSequence
-	 * 
-	 * Will build the correct loading sequence for the JS files in application based on the class, 
-	 * extends and depends statements in the files itself. It will first extract the class 
-	 * definitions and dependencies. It will put that information in a list that holds the 
+	 *
+	 * Will build the correct loading sequence for the JS files in application based on the class,
+	 * extends and depends statements in the files itself. It will first extract the class
+	 * definitions and dependencies. It will put that information in a list that holds the
 	 * dependencies for each file. With that list the proper sequence of loading can be constructed.
 	 * Files that originate from any of the specified coreFiles folders will be marked as core files.
 	 * @param $files Array List of files that have to be included.
@@ -410,7 +419,7 @@ class FileLoader {
 			$depends = Array();
 			$dependsFile = Array();
 			$class = Array();
-			
+
 			preg_match_all('(@extends\W([^\n\r]*))', $content, $extends);
 			preg_match_all('(@class\W([^\n\r]*))', $content, $class);
 			preg_match_all('(#depends\W([^\n\r\*]+))', $content, $depends);
@@ -507,16 +516,16 @@ class FileLoader {
 
 	/**
 	 * generateDependencyBasedFileSeq
-	 * 
-	 * This function will generate a loading sequence for the supplied list of files and their 
+	 *
+	 * This function will generate a loading sequence for the supplied list of files and their
 	 * dependencies. This function calculates the depth of each file in the dependencytree. Based on
-	 * that depth it calculates a weight for each file and that will determine the order in which 
-	 * the files will be included. 
-	 * The weight consists of two times the depth of the node and a penalty for files that have not 
+	 * that depth it calculates a weight for each file and that will determine the order in which
+	 * the files will be included.
+	 * The weight consists of two times the depth of the node and a penalty for files that have not
 	 * been marked as a core file. This way core files get included prior to other files at the same
 	 * depth. Files with the same weight are added in the order they are in the list and that should
 	 * be alphabetically.
-	 * 
+	 *
 	 * @param $fileData Array List of files with dependency data in the format of
 	 *                        $fileData[ FILENAME ] = Array(
 	 *                          'depends' => Array(FILENAME1, FILENAME2),
@@ -564,7 +573,7 @@ class FileLoader {
 			}
 		}
 
-		// If not all the files have been assigned a depth, but nothing changed the last round there 
+		// If not all the files have been assigned a depth, but nothing changed the last round there
 		// must be something wrong with the dependencies of the skipped files. So lets tell someone.
 		if(count($fileDepths) < count($fileData)){
 			$errorMsg = '[LOADER] Could not compute all dependecies. The following files cannot be resolved properly: ';
@@ -585,7 +594,7 @@ class FileLoader {
 				// Make up a weight to put it at the end
 				$weight = count($fileData);
 			}
-			if(!isset($fileWeights[ $weight])) 
+			if(!isset($fileWeights[ $weight]))
 				$fileWeights[ $weight ] = Array();
 			$fileWeights[ $weight ][] = $file;
 		}
@@ -593,7 +602,7 @@ class FileLoader {
 		// The weights have not been added in the correct order, so sort it first on the keys.
 		ksort($fileWeights);
 
-		// Now put it all in the correct order. Files with the same weight are added in the order 
+		// Now put it all in the correct order. Files with the same weight are added in the order
 		// they are in the list. This order should still be alphabetically.
 		$fileSequence = Array();
 		foreach($fileWeights as $weight => $fileList){
@@ -601,7 +610,7 @@ class FileLoader {
 				$fileSequence[] = $fileList[$i];
 			}
 		}
-		
+
 		return $fileSequence;
 	}
 
