@@ -1,9 +1,14 @@
 <?php
 	$user = sanitizeGetValue('user', '', USERNAME_REGEX);
-	$params = '?logon';
 
-	if(!empty($user)) {
-		$params .= '&user=' . $user;
+	$url = '?logon';
+	foreach($_GET as $key => $value) {
+		if(!empty($key) && !in_array($key, array('logon', 'load'))){
+			$url.= '&' . $key;
+			if(!empty($value)) {
+				$url.= '=' . urlencode($value);
+			}
+		}
 	}
 
 	$version = trim(file_get_contents('version'));
@@ -34,6 +39,8 @@
 					document.getElementById("username").focus();
 				}else if (document.getElementById("password").value == ""){
 					document.getElementById("password").focus();
+				} else {
+					document.getElementById("submitbutton").focus();
 				}
 			}
 		</script>
@@ -42,7 +49,7 @@
 		<table id="layout">
 			<tr><td>
 				<div id="login_main">
-					<form action="index.php<?= $params ?>" method="post">
+					<form action="index.php<?= $url ?>" method="post">
 						<div id="login_data">
 							<p><?=!(isset($GLOBALS["hresult"]))?_("Please logon"):"&nbsp;"?></p>
 							<p class="error"><?php
