@@ -95,6 +95,8 @@ $version = trim(file_get_contents('version'));
 				enable_advanced_settings	: <?= ENABLE_ADVANCED_SETTINGS ? 'true' : 'false' ?>,
 				max_attachments			: undefined,
 				max_attachment_size		: <?= getMaxUploadSize() ?>,
+				post_max_size			: <?= getMaxPostRequestSize() ?>,
+				max_file_uploads		: <?= getMaxFileUploads() ?>,
 				max_attachment_total_size	: undefined,
 				freebusy_load_start_offset : <?= FREEBUSY_LOAD_START_OFFSET ?>,
 				freebusy_load_end_offset : <?= FREEBUSY_LOAD_END_OFFSET ?>
