@@ -116,7 +116,19 @@
 		} else if (!empty($username) && !empty($password)) {
 			// Set the session variables if it is posted
 			$_SESSION['username'] = $username;
-			$_SESSION['password'] = $password;
+
+			// if user has openssl module installed
+			if(function_exists("openssl_encrypt")) {
+				// In PHP 5.3.3 the iv parameter was added
+				if(version_compare(phpversion(), "5.3.3", "<")) {
+					$_SESSION['password'] = openssl_encrypt($password,"des-ede3-cbc",PASSWORD_KEY,0);
+				} else {
+					$_SESSION['password'] = openssl_encrypt($password,"des-ede3-cbc",PASSWORD_KEY,0,PASSWORD_IV);
+				}
+			}
+			else {
+				$_SESSION['password'] = $password;
+			}
 		}
 
 	} else if (!DISABLE_REMOTE_USER_LOGIN && !isset($_SESSION['username'])) {
@@ -133,18 +145,6 @@
 		}
 	}
 
-	$urlAction = sanitizeGetValue('action', '', STRING_REGEX);
-	if(!empty($urlAction)) {
-		// get data from url and store it in session, which can be maintained across lots of redirects
-		// between login.php and welcome.php and webclient.php
-		storeURLDataToSession();
-
-		// after storing data in session we can refresh the page to remove url data
-		// and restore normal url for webapp
-		header('Location: index.php', true, 303);
-		exit;
-	}
-
 	// Create global mapi object. This object is used in many other files
 	$GLOBALS["mapisession"] = new MAPISession(session_id());
 
@@ -164,6 +164,18 @@
 	if ($GLOBALS["mapisession"]->isLoggedOn()) {
 		// Authenticated
 
+		$urlAction = sanitizeGetValue('action', '', STRING_REGEX);
+		if(!empty($urlAction)) {
+			// get data from url and store it in session, which can be maintained across lots of redirects
+			// between login.php and welcome.php and webclient.php
+			storeURLDataToSession();
+
+			// after storing data in session we can refresh the page to remove url data
+			// and restore normal url for webapp
+			header('Location: index.php', true, 303);
+			exit;
+		}
+
 		// Instantiate Plugin Manager
 		$GLOBALS['PluginManager'] = new PluginManager(ENABLE_PLUGINS);
 		$GLOBALS['PluginManager']->detectPlugins(DISABLED_PLUGINS_LIST);
