@@ -52,8 +52,11 @@ class PluginFeedback extends Plugin {
 	 *  @param $data
 	 */
 	function addJiraJsFile(&$data) {
-		//removing https: provides protocols compatibility, especially in IE9
-		$data['files'][] = '//jira.zarafa.com/s/en_US-cvcopm/773/8/1.2.2/_/download/batch/com.atlassian.jira.collector.plugin.jira-issue-collector-plugin:issuecollector/com.atlassian.jira.collector.plugin.jira-issue-collector-plugin:issuecollector.js?collectorId=d6b19906';
+		// make sure to load remote files only when plugin is enabled
+		if($GLOBALS['settings']->get('zarafa/v1/plugins/feedback/enable') == true) {
+			//removing https: provides protocols compatibility, especially in IE9
+			$data['files'][] = '//jira.zarafa.com/s/en_US-cvcopm/773/8/1.2.2/_/download/batch/com.atlassian.jira.collector.plugin.jira-issue-collector-plugin:issuecollector/com.atlassian.jira.collector.plugin.jira-issue-collector-plugin:issuecollector.js?collectorId=d6b19906';
+		}
 	}
 
 	/**
