@@ -1,4 +1,5 @@
 Ext.namespace("Zarafa.plugins.zdeveloper");
 Zarafa.plugins.zdeveloper.ZDeveloperPlugin=Ext.extend(Zarafa.core.Plugin,{initPlugin:function(){Zarafa.plugins.zdeveloper.ZDeveloperPlugin.superclass.initPlugin.apply(this,arguments);this.registerInsertionPoint(/(.*?)/,this.putMessageBox,this)},putMessageBox:function(a){if(a==="main.categories")return _("INSERT")+": "+a;else if(a.match(/(.*?).tabs/))return{xtype:"panel",title:a,listeners:{added:function(){Ext.get(this.tabEl.lastChild).addClass("zdeveloper-insertion-point")},delay:1,single:true}};
 else if(a=="navigation.center")return{xtype:"zarafa.contextnavigation",items:[{xtype:"box",autoEl:{tag:"div",html:a,cls:"zdeveloper-insertion-point"}}],context:container.getCurrentContext()};else if(a=="context.settings.categories")return{xtype:"zarafa.settingscategory",title:a,iconCls:"zdeveloper-insertion-point",items:[]};else if(a.match(/(.*?)toolbar(.*?)/)&&a!=="previewpanel.toolbar.detaillinks")return{xtype:"button",text:a,cls:"zdeveloper-insertion-point",listeners:{render:function(){this.text||
-this.setText(Ext.isObject(this.tooltip)?this.tooltip.title:this.tooltip)}}};else if(a!="main.content")return{xtype:"box",autoEl:{tag:"div",html:a,cls:"zdeveloper-insertion-point"}}}});Zarafa.onReady(function(){container.registerPlugin(new Zarafa.core.PluginMetaData({name:"zdeveloper",displayName:_("ZDeveloper"),pluginConstructor:Zarafa.plugins.zdeveloper.ZDeveloperPlugin}))});
+this.setText(Ext.isObject(this.tooltip)?this.tooltip.title:this.tooltip)}}};else if(a=="context.mail.gridrow")return String.format('<td style="width: 112px"><div class="{0}">{1}</div></td>',"grid_compact zdeveloper-insertion-point","context.mail.gridrow");else if(a=="context.mail.griddefaultcolumn")return{header:'<p class="zdeveloper-insertion-point">context.mail.griddefaultcolumn</p>',width:200,renderer:function(){return"context.mail.griddefaultcolumn"},tooltip:_("Sort by: context.mail.griddefaultcolumn")};
+else if(a!="main.content")return{xtype:"box",autoEl:{tag:"div",html:a,cls:"zdeveloper-insertion-point"}}}});Zarafa.onReady(function(){container.registerPlugin(new Zarafa.core.PluginMetaData({name:"zdeveloper",displayName:_("ZDeveloper"),pluginConstructor:Zarafa.plugins.zdeveloper.ZDeveloperPlugin}))});
