@@ -393,6 +393,10 @@ class AttachmentState {
 
 		// remove base directory also
 		if(is_dir($this->sessiondir)) {
+			// Directory should be empty to remove it, So first remove all files in the directory
+			if(function_exists("glob")) {
+				array_map('unlink', glob($this->sessiondir . "/*"));
+			}
 			rmdir($this->sessiondir);
 		}
 	}
