@@ -95,7 +95,23 @@
 
 			try {
 				// logon
+				if(function_exists("openssl_decrypt")) {
+					// In PHP 5.3.3 the iv parameter was added
+					if(version_compare(phpversion(), "5.3.3", "<")) {
+						$password = openssl_decrypt($password,"des-ede3-cbc",PASSWORD_KEY,0);
+					} else {
+						$password = openssl_decrypt($password,"des-ede3-cbc",PASSWORD_KEY,0,PASSWORD_IV);
+					}
+				}
 				$this->session = mapi_logon_zarafa($username, $password, $server, $sslcert_file, $sslcert_pass);
+				if(function_exists("openssl_encrypt")) {
+					// In PHP 5.3.3 the iv parameter was added
+					if(version_compare(phpversion(), "5.3.3", "<")) {
+						$password = openssl_encrypt($password,"des-ede3-cbc",PASSWORD_KEY,0);
+					} else {
+						$password = openssl_encrypt($password,"des-ede3-cbc",PASSWORD_KEY,0,PASSWORD_IV);
+					}
+				}
 
 				if ($this->session !== false){
 					$this->session_info["username"] = $username;
@@ -335,6 +351,35 @@
 			}
 		}
 
+		/**
+		 * Get single store and it's archive store aswell if we are openig full store.
+		 * 
+		 * @param $store object the store of the user
+		 * @param array $storeOptions contains folder_type of which folder to open
+		 * It is mapped to username, If folder_type is 'all' (i.e. Open Entire Inbox)
+		 * then we will open full store and it's archived stores.
+		 * @param String $username The username
+		 * @return Array storeArray The array of stores containg user's store and archived stores
+		 */
+		function getSingleMessageStores($store, $storeOptions, $username)
+		{
+			$storeArray = array($store);
+			$archivedStores = array();
+
+			// Get archived stores for user if there's any
+			if(!empty($username)) {
+				// Check whether we should open the whole store or just single folders
+				if(is_array($storeOptions) && isset($storeOptions[ $username ]) && isset($storeOptions[ $username ]['all'])) {
+					$archivedStores = $this->getArchivedStores($this->resolveStrictUserName($username));
+				}
+			}
+
+			foreach($archivedStores as $archivedStore) {
+				$storeArray[]= $archivedStore;
+			}
+			return $storeArray;
+		}
+
 		/**
 		 * Get the public message store
 		 *
@@ -361,7 +406,7 @@
 		function getAllMessageStores()
 		{
 			$this->loadMessageStoresFromSession();
-
+			$this->getArchivedStores($this->getUserEntryID());
 			// The cache now contains all the stores in our profile. Next, add the stores
 			// for other users.
 			$otherusers = $this->retrieveOtherUsersFromSettings();
@@ -373,6 +418,11 @@
 
 							$this->openMessageStore($user_entryid);
 							$this->userstores[$username] = $user_entryid;
+
+							// Check if an entire store will be loaded, if so load the archive store as well
+							if(isset($folder['all']) && $folder['all']['folder_type'] == 'all'){
+								$this->getArchivedStores($this->resolveStrictUserName($username));
+							}
 						} catch (MAPIException $e) {
 							if ($e->getCode() == MAPI_E_NOT_FOUND) {
 								// The user or the corresponding store couldn't be found,
@@ -421,22 +471,62 @@
 		}
 
 		/**
-		 * Resolve a username to its entryid
-		 *
-		 * @return string Entryid of the user on success, false otherwise
+		 * Searches for the PR_EC_ARCHIVE_SERVERS property of the user of the passed entryid in the 
+		 * Addressbook. It will get all his archive store objects and add those to the $this->stores
+		 * list. It will return an array with the list of archive stores where the key is the 
+		 * entryid of the store and the value the store resource.
+		 * @param String $userEntryid Binary entryid of the user
+		 * @return MAPIStore[] List of store resources with the key being the entryid of the store
 		 */
-		function resolveUserName($username)
+		function getArchivedStores($userEntryid)
 		{
-			$request = array(array(PR_DISPLAY_NAME => $username));
+			$ab = $this->getAddressbook();
+			$abitem = mapi_ab_openentry($ab, $userEntryid);
+			$userData = mapi_getprops($abitem, Array(PR_ACCOUNT, PR_EC_ARCHIVE_SERVERS));
 
-			try {
-				$ret = mapi_ab_resolvename($this->getAddressbook(), $request);
-				$result = $ret[0][PR_ENTRYID];
-			} catch (MAPIException $e) {
-				return $e->getCode();
+			// Get the store of the user, need this for the call to mapi_msgstore_getarchiveentryid()
+			$userStoreEntryid = mapi_msgstore_createentryid($this->getDefaultMessageStore(), $userData[PR_ACCOUNT]);
+			$userStore = mapi_openmsgstore($GLOBALS['mapisession']->getSession(), $userStoreEntryid);
+
+			$archiveStores = Array();
+			if(isset($userData[PR_EC_ARCHIVE_SERVERS]) && count($userData[PR_EC_ARCHIVE_SERVERS]) > 0){
+				for($i=0;$i<count($userData[PR_EC_ARCHIVE_SERVERS]);$i++){
+					try{
+						// Check if the store exists. It can be that the store archiving has been enabled, but no 
+						// archived store has been created an none can be found in the PR_EC_ARCHIVE_SERVERS property.
+						$archiveStoreEntryid = mapi_msgstore_getarchiveentryid($userStore, $userData[PR_ACCOUNT], $userData[PR_EC_ARCHIVE_SERVERS][$i]);
+						$archiveStores[$archiveStoreEntryid] = mapi_openmsgstore($GLOBALS['mapisession']->getSession(), $archiveStoreEntryid);
+						// Add the archive store to the list
+						$this->stores[$archiveStoreEntryid] = $archiveStores[$archiveStoreEntryid];
+					} catch (MAPIException $e) {
+						$e->setHandled();
+						if ($e->getCode() == MAPI_E_UNKNOWN_ENTRYID){
+							dump('Failed to load archive store as entryid is not valid' . $e->getDisplayMessage());
+						} else if ($e->getCode() == MAPI_E_NOT_FOUND) {
+							// The corresponding store couldn't be found, print an error to the log.
+							dump('Corresponding archive store couldn\'t be found' . $e->getDisplayMessage());
+						} else {
+							dump('Failed to load archive store' . $e->getDisplayMessage());
+						}
+					}
+				}
 			}
+			return $archiveStores;
+		}
 
-			return $result;
+		/**
+		 * Resolve the username strictly by opening that user's store and returning the 
+		 * PR_MAILBOX_OWNER_ENTRYID. This can be used for resolving an username without the risk of 
+		 * ambiguity since mapi_ab_resolve() does not strictly resolve on the username.
+		 * @param String $username The username
+		 * @return Binary|Integer Entryid of the user on success otherwise the hresult error code
+		 */
+		function resolveStrictUserName($username)
+		{
+			$storeEntryid = mapi_msgstore_createentryid($this->getDefaultMessageStore(), $username);
+			$store = mapi_openmsgstore($this->getSession(), $storeEntryid);
+			$storeProps = mapi_getprops($store, Array(PR_MAILBOX_OWNER_ENTRYID));
+			return $storeProps[PR_MAILBOX_OWNER_ENTRYID];
 		}
 
 		/**
@@ -568,11 +658,13 @@
 				// Get information about all contact folders from own store, shared stores and public store
 				$defaultStore = $this->getDefaultMessageStore();
 				$contactFolders = $this->getContactFoldersForABContactProvider($defaultStore);
-				$publicStore = $this->getPublicMessageStore();
 
-				// get contact folders from public store if public store exists
-				if($publicStore !== false) {
-					$contactFolders = array_merge($contactFolders, $this->getContactFoldersForABContactProvider($publicStore));
+				// include contact folders in addressbook if public folders are enabled, and Public contact folders is also disabled 
+				if(!DISABLE_PUBLIC_CONTACT_FOLDERS && ENABLE_PUBLIC_FOLDERS) {
+					$publicStore = $this->getPublicMessageStore();
+					if($publicStore !== false) {
+						$contactFolders = array_merge($contactFolders, $this->getContactFoldersForABContactProvider($publicStore));
+					}
 				}
 				//TODO: The shared stores are not opened as there still is a bug that does not allow resolving from shared contact folders
 
@@ -600,13 +692,8 @@
 
 		/**
 		 * Get the store entryid, folder entryid and display name of the contact folders in the
-		 * user's store. It returns an array where each item contains the information of one folder
-		 * formatted like this:
-		 * Array(
-		 *     PR_STORE_ENTRYID => '1234567890ABCDEF',
-		 *     PR_ENTRYID       => '1234567890ABCDEF',
-		 *     PR_DISPLAY_NAME  => 'Contact folder'
-		 * )
+		 * user's store. It returns an array prepared by getContactFolders.
+		 *
 		 * @param mapiStore $store The mapi store to look for folders in
 		 * @return Array Contact folder information
 		 */
@@ -621,11 +708,35 @@
 			}else{
 				$subtreeEntryid = $storeProps[PR_IPM_SUBTREE_ENTRYID];
 			}
-			$ipmSubtree = mapi_msgstore_openentry($store, $subtreeEntryid);
-			// Only searches one level deep, otherwise deleted contact folders will also be included.
-			// To search for multiple levels CONVENIENT_DEPTH needs to be passed as well.
-			$hierarchyTable = mapi_folder_gethierarchytable($ipmSubtree, MAPI_DEFERRED_ERRORS);
 
+			// Only searches one level deep, otherwise deleted contact folders will also be included.
+			$contactFolders = array();
+			$contactFolders = $this->getContactFolders($store, $subtreeEntryid, false);
+			// Need to search all the contact-subfolders within first level contact folders.
+			$firstLevelHierarchyNodes = $contactFolders;
+			foreach ($firstLevelHierarchyNodes as $key => $firstLevelNode) {
+				// To search for multiple levels CONVENIENT_DEPTH needs to be passed as well.
+				$contactFolders = array_merge($contactFolders, $this->getContactFolders($store, $firstLevelNode[PR_ENTRYID], true));
+			}
+			return $contactFolders;
+		}
+
+		/**
+		 * Get the store entryid, folder entryid and display name of the contact folders from within given folder, in the
+		 * user's store. It provides an array where each item contains the information of a folder
+		 * formatted like this:
+		 * Array(
+		 *     PR_STORE_ENTRYID => '1234567890ABCDEF',
+		 *     PR_ENTRYID       => '1234567890ABCDEF',
+		 *     PR_DISPLAY_NAME  => 'Contact folder'
+		 * )
+		 * @param mapiStore $store The mapi store of the user
+		 * @param string $folderEntryid EntryID of the folder to look for contact folders in
+		 * @param int $depthSearch flag to search into all the folder levels
+		 * @return Array an array in which founded contact-folders will be pushed
+		 */
+		function getContactFolders($store, $folderEntryid, $depthSearch)
+		{
 			$restriction = array(RES_CONTENT,
 				array(
 					// Fuzzylevel PF_PREFIX also allows IPF.Contact.Custom folders to be included.
@@ -638,8 +749,19 @@
 				)
 			);
 
-			mapi_table_restrict($hierarchyTable, $restriction, TBL_BATCH);
-			return mapi_table_queryallrows($hierarchyTable, array(PR_STORE_ENTRYID, PR_ENTRYID, PR_DISPLAY_NAME));
+			// Set necessary flag(s) to search considering all the sub folders or not
+			$depthFlag = MAPI_DEFERRED_ERRORS;
+			if ($depthSearch) {
+				$depthFlag |= CONVENIENT_DEPTH;
+			}
+
+			$hierarchyFolder = mapi_msgstore_openentry($store, $folderEntryid);
+
+			// Filter-out contact folders only
+			$contactFolderTable = mapi_folder_gethierarchytable($hierarchyFolder, $depthFlag);
+			mapi_table_restrict($contactFolderTable, $restriction, TBL_BATCH);
+
+			return mapi_table_queryallrows($contactFolderTable, array(PR_STORE_ENTRYID, PR_ENTRYID, PR_DISPLAY_NAME));
 		}
 	}
 ?>
