@@ -228,6 +228,7 @@
 				$properties["message_size"] = PR_MESSAGE_SIZE;
 				$properties["hasattach"] = PR_HASATTACH;
 
+				$properties["attach_num"] = PR_ATTACH_NUM;
 				$properties["sent_representing_entryid"] = PR_SENT_REPRESENTING_ENTRYID;
 				$properties["sent_representing_name"] = PR_SENT_REPRESENTING_NAME;
 				$properties["sent_representing_address_type"] = PR_SENT_REPRESENTING_ADDRTYPE;
@@ -437,6 +438,9 @@
 				$properties["fax_3_original_display_name"] = "PT_STRING8:PSETID_Address:0x80D4";
 				$properties["fax_3_original_entryid"] = "PT_BINARY:PSETID_Address:0x80D5";
 
+				$properties["has_picture"] = "PT_BOOLEAN:PSETID_Address:0x8015";
+				$properties["hide_attachments"] = "PT_BOOLEAN:PSETID_Common:0x8514";
+
 				// Properties for addresses
 				// Home address
 				$properties["home_address_street"] = PR_HOME_ADDRESS_STREET;
@@ -840,6 +844,7 @@
 				$properties["read_receipt_requested"] = PR_READ_RECEIPT_REQUESTED;
 				$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
 				$properties["transport_message_headers"] = PR_TRANSPORT_MESSAGE_HEADERS;
+				$properties["x_original_to"] = "PT_STRING8:PS_INTERNET_HEADERS:x-original-to";
 
 				// Corresponding appointment related properties
 				$properties["appointment_startdate"] = "PT_SYSTIME:PSETID_Appointment:0x820d";
