@@ -118,6 +118,14 @@
 					}
 
 					if($send) {
+						// Allowing to hook in just before the data sent away to be sent to the client
+						$GLOBALS['PluginManager']->triggerHook('server.module.createmailitemmodule.beforesend', array(
+							'moduleObject' => $this,
+							'store' => $store,
+							'entryid' => $entryid,
+							'action' =>$action,
+							));
+
 						$prop = Conversion::mapXML2MAPI($this->properties, $action['props']);
 
 						$result = $GLOBALS['operations']->submitMessage($store, $entryid, Conversion::mapXML2MAPI($this->properties, $action['props']), $messageProps, isset($action['recipients']) ? $action['recipients'] : array(), isset($action['attachments']) ? $action['attachments'] : array(), $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly);
@@ -138,7 +146,20 @@
 							$this->sendFeedback($result ? true : false, array(), false);
 						}
 					} else {
-						$result = $GLOBALS['operations']->saveMessage($store, $entryid, $parententryid, Conversion::mapXML2MAPI($this->properties, $action['props']), $messageProps, isset($action['recipients']) ? $action['recipients'] : array(), isset($action['attachments']) ? $action['attachments'] : array(), array(), $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly);
+						$propertiesToDelete = array();
+						$mapiProps = Conversion::mapXML2MAPI($this->properties, $action['props']);
+
+						/*
+						 * PR_SENT_REPRESENTING_ENTRYID and PR_SENT_REPRESENTING_SEARCH_KEY properties needs to be deleted while user removes 
+						 * any previously configured recipient from FROM field.
+						 * This property was simply ignored by Conversion::mapXML2MAPI function
+						 * as it is configured with empty string in request.
+						 */
+						if (isset($action['props']['sent_representing_entryid']) && empty($action['props']['sent_representing_entryid'])) {
+							array_push($propertiesToDelete, PR_SENT_REPRESENTING_ENTRYID,PR_SENT_REPRESENTING_SEARCH_KEY);
+						}
+
+						$result = $GLOBALS['operations']->saveMessage($store, $entryid, $parententryid, $mapiProps, $messageProps, isset($action['recipients']) ? $action['recipients'] : array(), isset($action['attachments']) ? $action['attachments'] : array(), $propertiesToDelete, $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly);
 
 						// Update the client with the (new) entryid and parententryid to allow the draft message to be removed when submitting.
 						// this will also update rowids of attachments which is required when deleting attachments
@@ -146,7 +167,21 @@
 						$props = mapi_getprops($result, array(PR_ENTRYID));
 						$savedMsg = $GLOBALS['operations']->openMessage($store, $props[PR_ENTRYID]);
 
-						$data = $GLOBALS['operations']->getMessageProps($store, $savedMsg, $this->properties);
+						$attachNum = !empty($action['attach_num']) ? $action['attach_num'] : false;
+
+						// If embedded message is being saved currently than we need to obtain all the 
+						// properties of 'embedded' message instead of simple message and send it in response
+						if($attachNum) {
+							$message = $GLOBALS['operations']->openMessage($store, $props[PR_ENTRYID], $attachNum);
+
+							if(empty($message)) {
+								return;
+							}
+
+							$data['item'] = $GLOBALS['operations']->getEmbeddedMessageProps($store, $message, $this->properties, $savedMsg, $attachNum);
+						} else {
+							$data = $GLOBALS['operations']->getMessageProps($store, $savedMsg, $this->properties);
+						}
 
 						/*
 						 * html filter modifies body of the message when opening the message
