@@ -1,7 +1,7 @@
 <?php
 	/**
 	 * ItemModule
-	 * Module which openes, creates, saves and deletes an item. It 
+	 * Module which openes, creates, saves and deletes an item. It
 	 * extends the Module class.
 	 */
 	class ItemModule extends Module
@@ -34,7 +34,7 @@
 
 			parent::Module($id, $data);
 		}
-		
+
 		/**
 		 * Executes all the actions in the $data variable.
 		 * @return boolean true on success of false on fialure.
@@ -64,7 +64,7 @@
 									 *   - declineMeetingRequest: attendee has declined mr
 									 */
 									if (isset($action["message_action"]) && isset($action["message_action"]["action_type"])) {
-										switch($action["message_action"]["action_type"]) 
+										switch($action["message_action"]["action_type"])
 										{
 											case "declineMeetingRequest":
 											case "acceptMeetingRequest":
@@ -72,8 +72,8 @@
 												$basedate = (isset($action['basedate']) ? $action['basedate'] : false);
 												$delete = false;
 												/**
-												 * Get message class from original message. This can be changed to 
-												 * IPM.Appointment if the item is a Meeting Request in the maillist. 
+												 * Get message class from original message. This can be changed to
+												 * IPM.Appointment if the item is a Meeting Request in the maillist.
 												 * After Accepting/Declining the message is moved and changed.
 												 */
 												$originalMessageProps = mapi_getprops($message, array(PR_MESSAGE_CLASS));
@@ -116,10 +116,10 @@
 												$GLOBALS["operations"]->publishFreeBusy($store);
 
 												/**
-												 * Now if the item is the Meeting Request that was sent to the attendee 
-												 * it is removed when the user has clicked on Accept/Decline. If the 
+												 * Now if the item is the Meeting Request that was sent to the attendee
+												 * it is removed when the user has clicked on Accept/Decline. If the
 												 * item is the appointment in the calendar it will not be moved. To only
-												 * notify the bus when the item is a Meeting Request we are going to 
+												 * notify the bus when the item is a Meeting Request we are going to
 												 * check the PR_MESSAGE_CLASS and see if it is "IPM.Meeting*".
 												 */
 												$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID));
@@ -269,7 +269,7 @@
 		 * Function does customization of exception based on module data.
 		 * like, here it will generate display message based on actionType
 		 * for particular exception.
-		 * 
+		 *
 		 * @param object $e Exception object
 		 * @param string $actionType the action type, sent by the client
 		 * @param MAPIobject $store Store object of message.
@@ -378,7 +378,7 @@
 		 * @param object $store MAPI Message Store Object
 		 * @param string $entryid entryid of the message
 		 * @param array $action the action data, sent by the client
-		 * @return boolean true on success or false on failure 
+		 * @return boolean true on success or false on failure
 		 */
 		function open($store, $entryid, $action)
 		{
@@ -400,6 +400,9 @@
 				return;
 			}
 
+			// Decode smime signed messages on this message
+ 			parse_smime($store, $message);
+
 			// Open embedded message if requested
 			$attachNum = !empty($action['attach_num']) ? $action['attach_num'] : false;
 			if($attachNum) {
@@ -486,7 +489,7 @@
 				} else if (stripos($messageClass, 'IPM.TaskRequest') !== false) {
 					$tr = new TaskRequest($store, $message, $GLOBALS['mapisession']->getSession());
 					$properties = $GLOBALS['properties']->getTaskProperties();
-					
+
 					if($tr->isTaskRequest()) {
 						$tr->processTaskRequest();
 						$task = $tr->getAssociatedTask(false);
@@ -500,7 +503,7 @@
 							PR_STORE_ENTRYID => hex2bin($taskProps['store_entryid'])
 						));
 					}
-					
+
 					if($tr->isTaskRequestResponse()) {
 						$tr->processTaskResponse();
 						$task = $tr->getAssociatedTask(false);
@@ -533,13 +536,13 @@
 		 * @param object $store MAPI Message Store Object
 		 * @param string $parententryid parent entryid of the message
 		 * @param array $action the action data, sent by the client
-		 * @return boolean true on success or false on failure		 		 
+		 * @return boolean true on success or false on failure
 		 */
 		function save($store, $parententryid, $entryid, $action)
 		{
 			$result = false;
 			$resultFlags = false;
-			
+
 			if(isset($action["props"])) {
 				if(!$store) {
 					$store = $GLOBALS['mapisession']->getDefaultMessageStore();
@@ -554,7 +557,7 @@
 
 				if($store && $parententryid) {
 					$props = Conversion::mapXML2MAPI($this->properties, $action["props"]);
-					
+
 					$messageProps = array(); // props returned from saveMessage
 
 					// Save message
@@ -573,27 +576,27 @@
 				}
 			}
 		}
-		
+
 		/**
 		 * Function which deletes an item.
 		 * @param object $store MAPI Message Store Object
 		 * @param string $parententryid parent entryid of the message
-		 * @param string $entryid entryid of the message		 
+		 * @param string $entryid entryid of the message
 		 * @param array $action the action data, sent by the client
-		 * @return boolean true on success or false on failure		 		 
+		 * @return boolean true on success or false on failure
 		 */
 		function delete($store, $parententryid, $entryid, $action)
 		{
 			$result = false;
-			
+
 			if($store && $parententryid && $entryid) {
 				$props = array();
 				$props[PR_PARENT_ENTRYID] = $parententryid;
 				$props[PR_ENTRYID] = $entryid;
-	
+
 				$storeprops = mapi_getprops($store, array(PR_ENTRYID));
 				$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
-				
+
 				$result = $GLOBALS["operations"]->deleteMessages($store, $parententryid, $entryid, isset($action['soft_delete']) ? $action['soft_delete'] : false);
 
 				if($result) {
@@ -602,17 +605,17 @@
 				}
 			}
 		}
-		
+
 		/**
-		 * Function which returns the entryid of a default folder.		 		 		 
+		 * Function which returns the entryid of a default folder.
 		 * @param object $store MAPI Message Store Object
 		 * @param string $messageClass the class of the folder
-		 * @return string entryid of a default folder, false if not found		 		 
+		 * @return string entryid of a default folder, false if not found
 		 */
 		function getDefaultFolderEntryID($store, $messageClass)
 		{
 			$entryid = false;
-			
+
 			if($store) {
 				$rootcontainer = mapi_msgstore_openentry($store);
 				$rootcontainerprops = mapi_getprops($rootcontainer, array(PR_IPM_DRAFTS_ENTRYID, PR_IPM_APPOINTMENT_ENTRYID, PR_IPM_CONTACT_ENTRYID, PR_IPM_JOURNAL_ENTRYID, PR_IPM_NOTE_ENTRYID, PR_IPM_TASK_ENTRYID));
@@ -647,30 +650,30 @@
 						break;
 				}
 			}
-			
+
 			return $entryid;
 		}
-		
+
 		function resolveConflict($store, $parententryid, $entryid, $action)
 		{
-			
+
 			if(!is_array($entryid)) {
 				$entryid = array($entryid);
 			}
 			$srcmessage = mapi_openentry($GLOBALS["mapisession"]->getSession(), $entryid[0], 0);
 			if(!$srcmessage)
 				return false;
-			
+
 			$dstmessage = mapi_openentry($GLOBALS["mapisession"]->getSession(), hex2bin($action["conflictentryid"]), MAPI_MODIFY);
 			if(!$dstmessage)
 				return false;
-			
+
 			$srcfolder = mapi_openentry($GLOBALS["mapisession"]->getSession(), $parententryid, MAPI_MODIFY);
-			
+
 			$result = mapi_copyto($srcmessage, array(), array(PR_CONFLICT_ITEMS, PR_SOURCE_KEY, PR_CHANGE_KEY, PR_PREDECESSOR_CHANGE_LIST), $dstmessage);
 			if(!$result)
 				return $result;
-				
+
 			//remove srcmessage entryid from PR_CONFLICT_ITEMS
 			$props = mapi_getprops($dstmessage, array(PR_CONFLICT_ITEMS));
 			if(isset($props[PR_CONFLICT_ITEMS])){
@@ -692,20 +695,20 @@
 					mapi_deleteprops($dstmessage, array(PR_CONFLICT_ITEMS));
 				}
 			}
-			
-				
+
+
 			mapi_savechanges($dstmessage);
-			
+
 			$result = mapi_folder_deletemessages($srcfolder, $entryid);
-			
+
 			$props = array();
 			$props[PR_PARENT_ENTRYID] = $parententryid;
 			$props[PR_ENTRYID] = $entryid[0];
-			
+
 			$storeprops = mapi_getprops($store, array(PR_ENTRYID));
 			$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
 			$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_DELETE, $props);
-			
+
 			if(!$result)
 				return $result;
 		}
@@ -721,14 +724,14 @@
 		function copy($store, $parententryid, $entryids, $action)
 		{
 			$result = false;
-			
+
 			if($store && $parententryid && $entryids) {
 				$dest_store = $store;
 				if(isset($action["message_action"]["destination_store_entryid"])) {
 					$dest_storeentryid = hex2bin($action["message_action"]["destination_store_entryid"]);
 					$dest_store = $GLOBALS["mapisession"]->openMessageStore($dest_storeentryid);
 				}
-				
+
 				$dest_folderentryid = false;
 				if(isset($action["message_action"]["destination_parent_entryid"])) {
 					$dest_folderentryid = hex2bin($action["message_action"]["destination_parent_entryid"]);
@@ -776,7 +779,7 @@
 		}
 
 		/**
-		 * Function returns correspondent calendar item's properties attached 
+		 * Function returns correspondent calendar item's properties attached
 		 * with the meeting request/response/cancellation.
 		 * @param Meetingrequest $meetingRequestObject the meeting request object
 		 * using which function will fetch meeting request properties and return them.
