@@ -800,7 +800,7 @@
 			$isPrivate = (isset($item['props']['private']) && $item['props']['private'] === true);
 			$isSensitive = (isset($item['props']['sensitivity']) && $item['props']['sensitivity'] === SENSITIVITY_PRIVATE);
 
-			if($isPrivate && $isSensitive) {
+			if($isPrivate || $isSensitive) {
 				// check for delegate permissions for delegate store
 				if($this->storeProviderGuid !== false && $this->storeProviderGuid === ZARAFA_STORE_DELEGATE_GUID) {
 					// by default we should always hide the item if we are in delegate store
