@@ -36,12 +36,12 @@
 						);
 
 						/**
-						 * check content type that is send by browser because content type for
-						 * eml attachments will be message/rfc822, but this content type is used
-						 * for message-in-message embedded objects, so we have to send it as
+						 * content-type sent by browser for eml and ics attachments will be
+						 * message/rfc822 and text/calendar respectively, but these content types are
+						 * used for message-in-message embedded objects, so we have to send it as
 						 * application/octet-stream.
 						 */
-						if ($FILE['type'] == 'message/rfc822') {
+						if ($FILE['type'] == 'message/rfc822' || $FILE['type'] == 'text/calendar') {
 							$FILE['type'] = 'application/octet-stream';
 						}
 
@@ -61,23 +61,39 @@
 					// any illegal characters.
 					$filename = mb_basename(stripslashes($FILE['name']));
 
+					// set sourcetype as default if sourcetype is unset.
+					$sourcetype = isset($_POST['sourcetype']) ? $_POST['sourcetype'] : 'default';
+
 					// Move the uploaded file into the attachment state
 					$attachid = $attachment_state->addUploadedAttachmentFile($_REQUEST['dialog_attachments'], $filename, $FILE['tmp_name'], array(
 						'name'       => $filename,
 						'size'       => $FILE['size'],
 						'type'       => $FILE['type'],
-						'sourcetype' => 'default'
+						'sourcetype' => $sourcetype
 					));
 
 					$newfiles[] = $attachid;
-					$returnfiles[] = Array(
-						'props' => Array(
-							'attach_num' => -1,
-							'tmpname' => $attachid,
-							'name' => $filename,
-							'size' => $FILE['size']
-						)
-					);
+
+					if($sourcetype === 'contactphoto') {
+						$returnfiles[] = Array(
+							'props' => Array(
+								'attach_num' => -1,
+								'attachment_contactphoto' => true,
+								'tmpname' => $attachid,
+								'name' => $filename,
+								'size' => $FILE['size']
+							)
+						);
+					} else if($sourcetype === 'default') {
+						$returnfiles[] = Array(
+							'props' => Array(
+								'attach_num' => -1,
+								'tmpname' => $attachid,
+								'name' => $filename,
+								'size' => $FILE['size']
+							)
+						);
+					}
 				}
 
 				$return = Array(
