@@ -95,14 +95,15 @@
 	 * gets maximum upload size of attachment from php ini settings
 	 * important settings are upload_max_filesize and post_max_size
 	 * upload_max_filesize specifies maximum upload size for attachments
-	 * post_max_size specifies maximum size of a post request, we are uploading attachment using post method
-	 * that's why we need to check this also
+	 * post_max_size must be larger then upload_max_filesize.
 	 * these values are overwritten in .htaccess file of WA
+	 * 
+	 * @return string return max value either upload max filesize or post max size.
 	 */
 	function getMaxUploadSize($as_string = false)
 	{
 		$upload_max_value = strtoupper(ini_get('upload_max_filesize'));
-		$post_max_value = strtoupper(ini_get('post_max_size'));
+		$post_max_value = getMaxPostRequestSize();
 
 		/**
 		 * if POST_MAX_SIZE is lower then UPLOAD_MAX_FILESIZE, then we have to check based on that value
@@ -119,15 +120,6 @@
 			$upload_max_value = ((int) $upload_max_value) * 1024 * 1024 * 1024;
 		}
 
-		// calculate post_max_value value to bytes
-		if (strpos($post_max_value, "K")!== false){
-			$post_max_value = ((int) $post_max_value) * 1024;
-		} else if (strpos($post_max_value, "M")!== false){
-			$post_max_value = ((int) $post_max_value) * 1024 * 1024;
-		} else if (strpos($post_max_value, "G")!== false){
-			$post_max_value = ((int) $post_max_value) * 1024 * 1024 * 1024;
-		}
-
 		// check which one is larger
 		$value = $upload_max_value;
 		if($upload_max_value > $post_max_value) {
@@ -150,6 +142,40 @@
 		return $value;
 	}
 
+	/**
+	 * Gets maximum post request size of attachment from php ini settings.
+	 * post_max_size specifies maximum size of a post request, 
+	 * we are uploading attachment using post method
+	 * 
+	 * @return string returns the post request size with proper unit(MB, GB, KB etc.).
+	 */
+	function getMaxPostRequestSize()
+	{
+		$post_max_value = strtoupper(ini_get('post_max_size'));
+
+		// calculate post_max_value value to bytes
+		if (strpos($post_max_value, "K")!== false){
+			$post_max_value = ((int) $post_max_value) * 1024;
+		} else if (strpos($post_max_value, "M")!== false){
+			$post_max_value = ((int) $post_max_value) * 1024 * 1024;
+		} else if (strpos($post_max_value, "G")!== false){
+			$post_max_value = ((int) $post_max_value) * 1024 * 1024 * 1024;
+		}
+
+		return $post_max_value;
+	}
+
+	/**
+	 * Get maximum number of files that can be uploaded in single request from php ini settings.
+	 * max_file_uploads specifies maximum number of files allowed in post request.
+	 * 
+	 * @return number maximum number of files can uploaded in single request.
+	 */
+	function getMaxFileUploads()
+	{
+		return (int)ini_get('max_file_uploads');
+	}
+
 	/**
 	 * cleanTemp
 	 *
@@ -365,106 +391,16 @@
 	function storeURLDataToSession()
 	{
 		$data = array();
-		$params = array();
 
-		$urlData = $_SERVER['QUERY_STRING'];
+		$urlData = urldecode($_SERVER['QUERY_STRING']);
+		if(!empty($_GET['action']) && $_GET['action'] === 'mailto') {
+			$data['mailto'] = $_GET['to'];
 
-		if(!empty($urlData)) {
-			$urlData = rawurldecode($urlData);
-		} else {
-			return;
-		}
-
-		/*
-		 * mailto link separates mailto address with other data with sign(?), which
-		 * is taken as just regular string by php in $_GET variable, so separate the
-		 * string from '?' and put remaining data in mailtodata variable. It is also
-		 * possible that string contain '&' sign as urlencoded value, so rather
-		 * treating '&' as url query parameter separator, it will be treated as just
-		 * a string. So we need to parse that string manually aswell.
-		 *
-		 * e.g. mailto:someone@zarafa.com?subject=Subject string&body=Body String
-		 */
-		$parts = preg_split('/[?&]/', $urlData, null, PREG_SPLIT_NO_EMPTY);
-
-		if(!empty($parts[1])) {
-			foreach ($parts as $key=>$pair) {
-				$values = explode('=', $pair);
-
-				if(!empty($values[0]) && !empty($values[1])) {
-					$params[strtolower($values[0])] = rawurldecode($values[1]);
-				}
-			}
-		}
-
-		// get data for mailto action
-		if(!empty($params['action']) && $params['action'] === 'mailto') {
-			$mailToData = array();
-
-			// get data for recipients
-			$recipients = array();
-
-			foreach (array('to', 'cc', 'bcc') as $recipType)
-			{
-				if(!isset($params[$recipType])) {
-					continue;
-				}
-
-				$value = $params[$recipType];
-				if($recipType === 'to') {
-					// remove mailto prefix from passed data
-					$value = str_replace('mailto:', '', $value);
-				}
-
-				// TO, CC, BCC field may contain multiple email address with
-				// semicolon(;) or comma(,) as separator.
-				$values = array_map('trim', preg_split('/[;,]/', $value, null, PREG_SPLIT_NO_EMPTY));
-
-				// Convert recipient types to mapi constants
-				$type = MAPI_TO;
-				if($recipType === 'cc') {
-					$type = MAPI_CC;
-				} else if ($recipType === 'bcc') {
-					$type = MAPI_BCC;
-				}
-
-				foreach ($values as $key=>$value) {
-					$value = sanitizeValue($value, '', ALLOWED_EMAIL_CHARS_REGEX);
-
-					if(!empty($value)) {
-						array_push($recipients, array('recipient_type' => $type, 'smtp_address' => $value));
-					}
-				}
-			}
-
-			if(!empty($recipients)) {
-				$mailToData['recipients'] = $recipients;
-			}
-
-			// get data for subject, we can't sanitize subject using regex because it can contain anything
-			if(!empty($params['subject'])) {
-				// we will remove html and php tags from subject as we don't support passing html data in mailto subject
-				// convert encoding to utf-8 to support umlauts
-				$subject = utf8_encode(strip_tags($params['subject']));
-
-				if(!empty($subject)) {
-					$mailToData['subject'] = $subject;
-				}
-			}
-
-			// get data for body, we can't sanitize body using regex because it can contain anything
-			if(!empty($params['body'])) {
-				// we will remove html and php tags from body as we don't support passing html data in mailto body
-				// convert encoding to utf-8 to support umlauts
-				$body = utf8_encode(strip_tags($params['body']));
-
-				if(!empty($body)) {
-					$mailToData['body'] = $body;
-				}
-			}
-
-			// add mailto data to array which will be stored in session
-			$data['mailto'] = $mailToData;
+			// There may be some data after to field, like cc, subject, body
+			// So add them in the urlData string aswell
+			$pos = stripos($urlData, $_GET['to']) + strlen($_GET['to']);
+			$subString = substr($urlData, $pos);
+			$data['mailto'] .= $subString;
 		}
 
 		if(!empty($data)) {
@@ -544,7 +480,7 @@
 	function parse_smime($store, $message)
 	{
 		$props = mapi_getprops($message, array(PR_MESSAGE_CLASS));
-
+		
 		if(isset($props[PR_MESSAGE_CLASS]) && stripos($props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME.MultipartSigned') !== false) {
 			// this is a signed message. decode it.
 			$atable = mapi_message_getattachmenttable($message);
@@ -562,10 +498,46 @@
 				$att = mapi_message_openattach($message, $attnum);
 				$data = mapi_openproperty($att, PR_ATTACH_DATA_BIN);
 
+				// Allowing to hook in before the signed attachment is removed
+				$GLOBALS['PluginManager']->triggerHook('server.util.parse_smime.signed', array(
+					'moduleObject' =>& $this,
+					'store' => $store,
+					'props' => $props,
+					'message' => &$message,
+					'data' => &$data
+					));
+
 				mapi_message_deleteattach($message, $attnum);
 
 				mapi_inetmapi_imtomapi($GLOBALS['mapisession']->getSession(), $store, $GLOBALS['mapisession']->getAddressbook(), $message, $data, Array("parse_smime_signed" => 1));
 			}
+		} else if(isset($props[PR_MESSAGE_CLASS]) && stripos($props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME') !== false) {
+			// this is a encrypted message. decode it.
+			$attachTable = mapi_message_getattachmenttable($message);
+
+			$rows = mapi_table_queryallrows($attachTable, Array(PR_ATTACH_MIME_TAG, PR_ATTACH_NUM));
+			$attnum = false;
+
+			foreach($rows as $row) {
+				if(isset($row[PR_ATTACH_MIME_TAG]) && in_array($row[PR_ATTACH_MIME_TAG],array('application/x-pkcs7-mime','application/pkcs7-mime')) ) {
+					$attnum = $row[PR_ATTACH_NUM];
+				}
+			}
+			if($attnum !== false){
+				$att = mapi_message_openattach($message, $attnum);
+				$data = mapi_openproperty($att, PR_ATTACH_DATA_BIN);
+
+				// Allowing to hook in before the encrypted attachment is removed
+				$GLOBALS['PluginManager']->triggerHook('server.util.parse_smime.encrypted', array(
+					'moduleObject' =>& $this,
+					'store' => $store,
+					'props' => $props,
+					'message' => &$message,
+					'data' => &$data
+					));
+
+				mapi_message_deleteattach($message, $attnum);
+			}
 		}
 	}
-?>
\ No newline at end of file
+?>
